@@ -7,7 +7,6 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
   Seed <- round(runif(min=(1+aantal), max=2147483647, n=1), digits=0)
   Seed.generalCase <- Seed   #for gen case LS
   
-  
   vector_b <- matrix(data=c(1, pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1), ncol=1)  
   
   sum_pi_f <- Pi.Vectors <- pi_f_all <- pi_r_all <- C3_all <- R2_H_all <- theta_T_all <- theta_S_all <- H_Delta_T_all <- pi_all <- NULL
@@ -25,8 +24,9 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     
     try(Pi.Vectors.No <- cbind(T_No$Pi.Vectors, "No"), silent=TRUE)
     try(Pi.Vectors.T <- cbind(T_True$Pi.Vectors[,1:5], 0, 0, 0, T_True$Pi.Vectors[,6:7], 0, T_True$Pi.Vectors[,8:13], "True"), silent=TRUE)
-    try(Pi.Vectors.S <- cbind(T_Surr$Pi.Vectors[,1:2], 0, T_Surr$Pi.Vectors[,3:5], 0, T_Surr$Pi.Vectors[,6], 0, T_Surr$Pi.Vectors[,7:9], 0,
-                              T_Surr$Pi.Vectors[,10:13], "Surr"), silent=TRUE)
+    try(Pi.Vectors.S <- cbind(T_Surr$Pi.Vectors[,1:2], 0, T_Surr$Pi.Vectors[,3:5], 0, T_Surr$Pi.Vectors[,8], 0, T_Surr$Pi.Vectors[,9],
+                              T_Surr$Pi.Vectors[,6], T_Surr$Pi.Vectors[,10], 0, T_Surr$Pi.Vectors[,7], 
+                              T_Surr$Pi.Vectors[,11:13], "Surr"), silent=TRUE)
     try(Pi.Vectors.ST <- cbind(T_SurrTrue$Pi.Vectors[,1:2], 0, T_SurrTrue$Pi.Vectors[,3:4], 0, 0, 0, 0, T_SurrTrue$Pi.Vectors[,5], 0,
                                T_SurrTrue$Pi.Vectors[,6], 0, T_SurrTrue$Pi.Vectors[,7:10], "SurrTrue"), silent=TRUE)
     
@@ -68,6 +68,24 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
                          1, 0, 1, 0, 1, 0, 0), ncol=9)
     A <- cbind(A_r, A_f)
     
+    
+    #restrictions
+    min_pi_1001 <- min(pi1_0_, pi_0_1)
+    min_pi_1110 <- min(pi1_1_, pi_1_0)
+    min_pi_1101 <- min(pi1_0_, pi_1_1)
+    min_pi_1011 <- min(pi1_1_, pi_0_1)
+    min_pi_1111 <- min(pi1_1_, pi_1_1)
+    min_pi_0110 <- min(pi0_1_, pi_1_0)
+    min_pi_0011 <- min(pi0_1_, pi_0_1)
+    min_pi_0111 <- min(pi0_1_, pi_1_1)
+    min_pi_1100 <- min(pi1_0_, pi_1_0)
+    
+    max_val <- min((min_pi_1001 + min_pi_1110 + min_pi_1101 + min_pi_1011 + min_pi_1111 + 
+      min_pi_0110 + min_pi_0011 + min_pi_0111 + min_pi_1100), 1)
+    min_val <- min(Sum_Pi_f)
+    by_val = (max(Sum_Pi_f)-min(Sum_Pi_f))/(length(Sum_Pi_f)-1)
+        Sum_Pi_f <- seq(min_val, max_val, by=by_val)
+    
     Sum_Pi_f_number <- length(Sum_Pi_f)
     
     for (k in 1: Sum_Pi_f_number){
@@ -103,14 +121,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           Delta_c_mat <-
             matrix(data=c(mat1, mat2, mat3, mat4, mat5, mat6, mat7, mat8, mat9), nrow=3)
           
-          #C3
-          pi_a <- mat1+mat5+mat9
-          pi_e <- ((mat1+mat4+mat7)*(mat1+mat2+mat3))+((mat2+mat5+mat8)*(mat4+mat5+mat6))+((mat3+mat6+mat9)*(mat7+mat8+mat9))
-          kappa <- (pi_a - pi_e)/(1-pi_e)
-          pi_max <- 
-            min(mat1+mat4+mat7, mat1+mat2+mat3) + min(mat2+mat5+mat8, mat4+mat5+mat6) + min(mat3+mat6+mat9, mat7+mat8+mat9)
-          k_max <- (pi_max - pi_e)/(1-pi_e)
-          C3 <- kappa/k_max
+          C3 <- 1
           C3_all <- cbind(C3_all, C3)
           
           #R2_H
@@ -162,7 +173,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     }
     
     num <- dim(R2_H_all)[2]
-    
+   
     if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
     
     sum_pi_f <- colSums(pi_all[8:16,]) 
@@ -170,6 +181,8 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
       data.frame(t(rbind(pi_all, sum_pi_f))) 
     colnames(Pi.Vectors) <- c("Pi_0000", "Pi_0100", "Pi_0010", "Pi_0001", "Pi_0101", "Pi_1000", "Pi_1010", 
                               "Pi_1001", "Pi_1110", "Pi_1101", "Pi_1011", "Pi_1111", "Pi_0110", "Pi_0011", "Pi_0111", "Pi_1100", "Sum.Pi.f") 
+
+    
     
   } # end no mono
   
@@ -192,8 +205,21 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     
     pi_f_all <- pi_r_all <- C3_all <- R2_H_all <- theta_T_all <- theta_S_all <- H_Delta_T_all <- NULL
     
+    #restrictions
+    min_pi_1111 <- min(pi1_1_, pi_1_1)
+    min_pi_0110 <- min(pi0_1_, pi_1_0)
+    min_pi_0011 <- min(pi0_1_, pi_0_1)
+    min_pi_0111 <- min(pi0_1_, pi_1_1)
+    min_pi_1100 <- min(pi1_0_, pi_1_0)
+    
+    max_val <- min((min_pi_1111 + min_pi_0110 + min_pi_0011 + min_pi_0111 + min_pi_1100), 1)
+    min_val <- min(Sum_Pi_f)
+    by_val = (max(Sum_Pi_f)-min(Sum_Pi_f))/(length(Sum_Pi_f)-1)
+    Sum_Pi_f <- seq(min_val, max_val, by=by_val)
     
     Sum_Pi_f_number <- length(Sum_Pi_f)
+    
+    
     for (k in 1: Sum_Pi_f_number){
       
       for (i in 1: M){
@@ -228,14 +254,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           Delta_c_mat <-
             matrix(data=c(mat1, mat2, mat3, mat4, mat5, mat6, mat7, mat8, mat9), nrow=3)
           
-          #C3
-          pi_a <- mat1+mat5+mat9
-          pi_e <- ((mat1+mat4+mat7)*(mat1+mat2+mat3))+((mat2+mat5+mat8)*(mat4+mat5+mat6))+((mat3+mat6+mat9)*(mat7+mat8+mat9))
-          kappa <- (pi_a - pi_e)/(1-pi_e)
-          pi_max <- 
-            min(mat1+mat4+mat7, mat1+mat2+mat3) + min(mat2+mat5+mat8, mat4+mat5+mat6) + min(mat3+mat6+mat9, mat7+mat8+mat9)
-          k_max <- (pi_max - pi_e)/(1-pi_e)
-          C3 <- kappa/k_max
+          C3 <- 1
           C3_all <- cbind(C3_all, C3)
           
           #R2_H
@@ -286,6 +305,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     
     num <- dim(R2_H_all)[2]
     
+    
     if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
     
     sum_pi_f <- colSums(pi_all[8:12,]) 
@@ -315,9 +335,21 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
                               1, 0, 1, 0, 1, 0, 0), ncol=5)
     A_star <- cbind(A_star_r, A_star_f)
     
+    #restrictions
+    min_pi_1001 <- min(pi1_0_, pi_0_1)
+    min_pi_1101 <- min(pi1_0_, pi_1_1)
+    min_pi_1111 <- min(pi1_1_, pi_1_1)
+    min_pi_0111 <- min(pi0_1_, pi_1_1)
+    min_pi_1100 <- min(pi1_0_, pi_1_0)
+    
+    max_val <- min((min_pi_1001 + min_pi_1101 + min_pi_1111 + min_pi_0111 + min_pi_1100), 1)
+    min_val <- min(Sum_Pi_f)
+    by_val = (max(Sum_Pi_f)-min(Sum_Pi_f))/(length(Sum_Pi_f)-1)
+    Sum_Pi_f <- seq(min_val, max_val, by=by_val)
     
     Sum_Pi_f_number <- length(Sum_Pi_f)
     
+    
     for (k in 1: Sum_Pi_f_number){
       
       for (i in 1: M){
@@ -352,14 +384,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           Delta_c_mat <-
             matrix(data=c(mat1, mat2, mat3, mat4, mat5, mat6, mat7, mat8, mat9), nrow=3)
           
-          #C3
-          pi_a <- mat1+mat5+mat9
-          pi_e <- ((mat1+mat4+mat7)*(mat1+mat2+mat3))+((mat2+mat5+mat8)*(mat4+mat5+mat6))+((mat3+mat6+mat9)*(mat7+mat8+mat9))
-          kappa <- (pi_a - pi_e)/(1-pi_e)
-          pi_max <- 
-            min(mat1+mat4+mat7, mat1+mat2+mat3) + min(mat2+mat5+mat8, mat4+mat5+mat6) + min(mat3+mat6+mat9, mat7+mat8+mat9)
-          k_max <- (pi_max - pi_e)/(1-pi_e)
-          C3 <- kappa/k_max
+          C3 <- 1
           C3_all <- cbind(C3_all, C3)
           
           #R2_H
@@ -409,18 +434,19 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
       }
     }
     
-    
     num <- dim(R2_H_all)[2]
     
-    if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
+   
+      if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
     
     sum_pi_f <- colSums(pi_all[8:12,]) 
     
     Pi.Vectors <- 
       data.frame(t(rbind(pi_all, sum_pi_f))) 
     colnames(Pi.Vectors) <- c("Pi_0000", "Pi_0100", "Pi_0001", "Pi_0101", "Pi_1000",  
-                              "Pi_1001", "Pi_1101", "Pi_1011", "Pi_1111", "Pi_0011", "Pi_0111", "Pi_1100", "Sum.Pi.f")   
+                              "Pi_1011", "Pi_0011", "Pi_1001", "Pi_1101", "Pi_1111", "Pi_0111", "Pi_1100", "Sum.Pi.f")   
     
+   
   } # end mono S  
   
   if (Monotonicity=="Surr.True.Endp"){  
@@ -438,7 +464,17 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     A_star <- cbind(A_star_r, A_star_f)
     
     
+    #restrictions
+    min_pi_0111 <- min(pi0_1_, pi_1_1)
+    min_pi_1100 <- min(pi1_0_, pi_1_0)
+    
+    max_val <- min((min_pi_0111 + min_pi_1100), 1)
+    min_val <- min(Sum_Pi_f)
+    by_val = (max(Sum_Pi_f)-min(Sum_Pi_f))/(length(Sum_Pi_f)-1)
+    Sum_Pi_f <- seq(min_val, max_val, by=by_val)
+    
     Sum_Pi_f_number <- length(Sum_Pi_f)
+    
     for (k in 1: Sum_Pi_f_number){
       
       for (i in 1: M){
@@ -473,14 +509,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           Delta_c_mat <-
             matrix(data=c(mat1, mat2, mat3, mat4, mat5, mat6, mat7, mat8, mat9), nrow=3)
           
-          #C3
-          pi_a <- mat1+mat5+mat9
-          pi_e <- ((mat1+mat4+mat7)*(mat1+mat2+mat3))+((mat2+mat5+mat8)*(mat4+mat5+mat6))+((mat3+mat6+mat9)*(mat7+mat8+mat9))
-          kappa <- (pi_a - pi_e)/(1-pi_e)
-          pi_max <- 
-            min(mat1+mat4+mat7, mat1+mat2+mat3) + min(mat2+mat5+mat8, mat4+mat5+mat6) + min(mat3+mat6+mat9, mat7+mat8+mat9)
-          k_max <- (pi_max - pi_e)/(1-pi_e)
-          C3 <- kappa/k_max
+          C3 <- 1
           C3_all <- cbind(C3_all, C3)
           
           #R2_H
@@ -528,7 +557,12 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
       }
     }
     
+    num <- dim(R2_H_all)[2]
     
+    
+      if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
+  
+        
     sum_pi_f <- colSums(pi_all[8:9,]) 
     Pi.Vectors <- 
       data.frame(t(rbind(pi_all, sum_pi_f))) 
@@ -538,8 +572,9 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
   } # end mono S and T
   
   fit <- 
-    list(Pi.Vectors= Pi.Vectors, C3=as.numeric(C3_all), R2_H=as.numeric(R2_H_all), Theta_T = as.numeric(theta_T_all), 
-         Theta_S = as.numeric(theta_S_all), H_Delta_T = as.numeric(H_Delta_T_all), Monotonicity=Monotonicity, Call=match.call())      
+    list(Pi.Vectors= Pi.Vectors, R2_H=as.numeric(R2_H_all), Theta_T = as.numeric(theta_T_all), 
+         Theta_S = as.numeric(theta_S_all), H_Delta_T = as.numeric(H_Delta_T_all), 
+         Monotonicity=Monotonicity, Call=match.call())      
   
   class(fit) <- "ICA.BinBin"
   fit
